"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import gcp.gcp_compute_route_pb2
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleComputeRoute(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_ROUTE_FIELD_NUMBER: builtins.int
    @property
    def compute_route(self) -> gcp.gcp_compute_route_pb2.ComputeRoute: ...
    def __init__(
        self,
        *,
        compute_route: gcp.gcp_compute_route_pb2.ComputeRoute | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compute_route", b"compute_route"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compute_route", b"compute_route"]) -> None: ...

global___GoogleComputeRoute = GoogleComputeRoute
