"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import gcp.gcp_redis_pb2
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleRedis(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REDIS_INSTANCE_FIELD_NUMBER: builtins.int
    @property
    def redis_instance(self) -> gcp.gcp_redis_pb2.RedisInstance: ...
    def __init__(
        self,
        *,
        redis_instance: gcp.gcp_redis_pb2.RedisInstance | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["redis_instance", b"redis_instance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["redis_instance", b"redis_instance"]) -> None: ...

global___GoogleRedis = GoogleRedis
